<?php
/*
Plugin Name: Namaste! LMS to WatuPRO Play Bridge
Plugin URI: 
Description: Lets you assign badges from WatuPRO Play for completing Namaste! LMS courses  
Author: Kiboko Labs
Version: 0.5
Author URI: http://calendarscripts.info/
License: GPLv2 or later
*/

define( 'NAMPLAY_PATH', dirname( __FILE__ ) );
define( 'NAMPLAY_RELATIVE_PATH', dirname( plugin_basename( __FILE__ )));
define( 'NAMPLAY_URL', plugin_dir_url( __FILE__ ));

register_activation_hook(__FILE__, 'namplay_activate');
add_action('init', 'namplay_init');

function namplay_activate() {
	global $wpdb;
	$wpdb -> show_errors();
	namplay_init();
   	
	
	if($wpdb->get_var("SHOW TABLES LIKE '".NAMPLAY_COURSE_BADGES."'") != NAMPLAY_COURSE_BADGES) {        
			$sql = "CREATE TABLE `" . NAMPLAY_COURSE_BADGES . "` (
				  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
					`course_id` INT UNSIGNED NOT NULL DEFAULT 0,
					`badge_id` INT UNSIGNED NOT NULL DEFAULT 0
				) DEFAULT CHARSET=utf8;";
			
			$wpdb->query($sql);
	  }
}

function namplay_init() {
	global $wpdb;
	
	define('NAMPLAY_COURSE_BADGES', $wpdb->prefix.'namplay_course_badges');
	
	add_action('namaste_lms_admin_menu', 'namplay_menu');
	add_action('namaste_completed_course', 'namplay_assign_badges', 10, 2);
	add_filter('watuproplay-adjust-points', 'namplay_adjust_watuproplay_points');
}

function namplay_menu() {
	$namaste_cap = current_user_can('namaste_options') ? 'manage_options' : 'namaste_manage';   	
	
	add_submenu_page('namaste_options', __('Badges for Courses', 'namplay'), __('Badges for Courses', 'namplay'), $namaste_cap, 'namplay_badges', 'namplay_badges');
}

// show the assignment
function namplay_badges() {
	global $wpdb;
	
	// select courses
	$courses = $wpdb->get_results("SELECT * FROM {$wpdb->posts}
		WHERE post_type = 'namaste_course'  AND (post_status='publish' OR post_status='draft')
		ORDER BY post_title");
	
	// select badges
	$badges = $wpdb -> get_results("SELECT * FROM ".WATUPROPLAY_LEVELS." WHERE atype='badge' ORDER BY name");	
	
	if(!empty($_POST['ok'])) {
		foreach($courses as $course) {
			// delete old assignments
			$wpdb->query($wpdb->prepare("DELETE FROM ".NAMPLAY_COURSE_BADGES." WHERE course_id=%d", $course->ID));
			
			if(!empty($_POST['badges_'.$course->ID])) {
				foreach($_POST['badges_'.$course->ID] as $badge_id) {
					$wpdb->query($wpdb->prepare("INSERT INTO ".NAMPLAY_COURSE_BADGES." SET
						course_id=%d, badge_id=%d", $course->ID, $badge_id));
				}
			}
		} // end foreach course
	}	// end save	
	
	// save the points transfer
	if(!empty($_POST['save_transfer_points'])) {
		update_option('namplay_transfer_points', $_POST['transfer_points']);
	}
	
	// select assigned badges
	$course_badges = $wpdb->get_results("SELECT * FROM ".NAMPLAY_COURSE_BADGES);
	
	// match badges to courses
	foreach($courses as $cnt=>$course) {
		$this_badges = array();
		foreach($course_badges as $course_badge) {
			if($course->ID == $course_badge->course_id) $this_badges[] = $course_badge->badge_id;
		}
		
		$courses[$cnt]->play_badges = $this_badges;
	}
	
	require(NAMPLAY_PATH."/views/course-badges.html.php");
}

// assigns proper badges when course is completed
function namplay_assign_badges($student_id, $course_id) {
	global $wpdb;
	
	// any badges to assign?	
	$course_badges = $wpdb->get_results($wpdb->prepare("SELECT * FROM ".NAMPLAY_COURSE_BADGES." WHERE course_id=%d", $course_id));
	
	if(!empty($course_badges)) {
		$user_badges = get_user_meta($student_id, 'watuproplay_user_badges', true);
		$user_badges = explode("|", $user_badges);
		
		$badges_to_assign = array();
		foreach($course_badges as $badge) {
			$badges_to_assign[] = $badge->badge_id;
			if(!@in_array($badge['badge_id'], $user_badges)) {		
					$wpdb->query( $wpdb->prepare("INSERT INTO ".WATUPROPLAY_HISTORY." SET
					user_id=%d, item_id=%d, action='assigned badge', timestamp=%d, datetime=NOW(), taking_id=%d",
					$student_id, $badge['badge_id'], time(), 0));
			} // end if badge doesn't already exist
		}
		update_user_meta($student_id, 'watuproplay_user_badges', "|".implode("|",$badges_to_assign)."|");
	}
}

// adjust the points in watupro play by simply adding the Namaste points to them
function namplay_adjust_watuproplay_points($points) {
	global $user_ID;
	if(get_option('namplay_transfer_points') != 1) return $points;		
	
	$namaste_points = get_user_meta($user_ID, 'namaste_points', true);
	$points += $namaste_points;
	
	return $points;
}